@@ -1,3 +1,4 @@
+#' @export 
 extractAIC.coxreg <- function(fit, scale, k = 2, ...) 
 {
     edf <- sum(fit$df)
@@ -5,6 +6,7 @@ extractAIC.coxreg <- function(fit, scale, k = 2, ...)
     c(edf, -2 * loglik + k * edf)
 }
 
+#' @export
 extractAIC.phreg <- function(fit, scale, k = 2, ...) 
 {
     edf <- sum(fit$df)
@@ -12,6 +14,7 @@ extractAIC.phreg <- function(fit, scale, k = 2, ...)
     c(edf, -2 * loglik + k * edf)
 }
 
+#' @export
 extractAIC.aftreg <- function(fit, scale, k = 2, ...) 
 {
     edf <- sum(fit$df)
@@ -19,33 +22,17 @@ extractAIC.aftreg <- function(fit, scale, k = 2, ...)
     c(edf, -2 * loglik + k * edf)
 }
 
+#' @export
 nobs.coxreg <- function(object, ...){
     object$n
 }
 
+#' @export
 nobs.phreg <- function(object, ...){
     object$n
 }
+
+#' @export
 nobs.aftreg <- function(object, ...){
     object$n
 }
-
-extractAIC.glmmML <- function(fit, scale, k = 2, ...) {
-    if (k != 2) warning("Only k = 2 is implemented")
-    edf <- length(fit$coefficients) + 1
-    c(edf, fit$aic)
-}
-
-extractAIC.glmmboot <- function(fit, scale, k = 2, ...) {
-    if (k != 2) warning("Only k = 2 is implemented")
-    edf <- length(fit$coefficients) + length(fit$frail)
-    c(edf, fit$aic)
-}
-
-nobs.glmmML <- function(object, ...){
-    object$n
-}
-
-nobs.glmmboot <- function(object, ...){
-    object$n
-}
