@@ -4,6 +4,9 @@ gompstartAft <- function(enter, exit, event){
     ##
     ## This is for ONE stratum only! So input is from only one!
 
+    ## NOTE: Revised in 2.3-2: Using the 'canonical' representation:
+    ## h(t, (gamma, alpha)) = exp(gamma - alpha) * exp(t * exp(-alpha))
+    
     ## Profiling; gamma is profiled out:
     D <- sum(event)
     logD <- log(D)
@@ -14,8 +17,10 @@ gompstartAft <- function(enter, exit, event){
         for (i in 1:n){
             ealpha <- exp(-alpha[i])
             S <- sum(exp(exit * ealpha) - exp(enter * ealpha))
-            gamma <- logD - alpha[i] - log(S)
-            loglik[i] <- D * gamma + DT * ealpha - D
+        ##    gamma <- logD - alpha[i] - log(S)
+            gamma <- logD - log(S) # 2.3-2
+        ##    loglik[i] <- D * gamma + DT * ealpha - D
+            loglik[i] <- D * (gamma - alpha[i]) + DT * ealpha - D # 2.3-2
         }
         loglik
     }
@@ -26,7 +31,8 @@ gompstartAft <- function(enter, exit, event){
     fit <- optim(alpha, funk, control = list(fnscale = -1), method = "BFGS")
     alpha <- fit$par
     S <- sum(exp(exit * exp(-alpha)) - exp(enter * exp(-alpha)))
-    gamma <- log(D) - alpha - log(S)
+    ## gamma <- log(D) - alpha - log(S)
+    gamma <- log(D) - log(S) # 2.3-2    
     ret <- c(alpha, gamma)
     ##names(ret) <- c("alpha", "gamma")
     ret
